#
# spec file for package python-django-appconf
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-appconf
Version:        1.1.0
Release:        1.1
Summary:        A Helper Class for Handling Configuration Defaults of Packaged Apps
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/django-compressor/django-appconf
Source:         https://github.com/django-compressor/django-appconf/archive/v%{version}.tar.gz
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django
BuildArch:      noarch
%python_subpackages

%description
A helper class for handling configuration defaults of packaged Django apps
gracefully.

%prep
%setup -q -n django-appconf-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export DJANGO_SETTINGS_MODULE=tests.test_settings
%pytest tests/tests.py

%files %{python_files}
%license LICENSE
%doc AUTHORS README.rst docs
%{python_sitelib}/appconf
%{python_sitelib}/django_appconf-%{version}*-info

%changelog
* Tue Apr 15 2025 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * Dropped official support for Python 3.7 and 3.8.
  * Dropped official support for Django 3.2, 4.0, 4.1, and 5.0.
  * Added official support for Django 5.2.
  * Updated some old code to use more modern conventions.
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.6:
  * Updated declared support and testing for Django 5.0 and 4.2,
    and Python 3.12.
* Wed Jun 21 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.5:
  * Adds testing against latest non-EOL Python and Django versions and
    updates package metadata accordingly.
* Mon Nov 21 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python-six dependency.
- Remove python_module macro definition
- More specific python_sitelib in %%files
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Thu May 20 2021 pgajdos@suse.com
- use %%pytest macro in %%check
* Fri Apr  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.4:
  * Updates test matrix and PyPI metadata for latest versions of Django.
* Fri Mar  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.3:
  * use six directly
  * metadata updates
* Mon Dec 10 2018 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github archives to get tests
- Run the tests
- Fix dependencies
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Tue Nov 15 2016 dmueller@suse.com
- update to 1.0.2:
  * Update supported Django and Python versions, in line with Django's
  own supported versions.
* Sun May  3 2015 benoit.monin@gmx.fr
- update to version 1.0.1:
  * no changelog
- additional changes from version 1.0:
  * Dropped support of Python 2.5.
  * Added support for Django 1.7 and 1.8.
  * Modernized test setup.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Sep  9 2013 speilicke@suse.com
- Drop obsolete versiontools build requirement
* Sun Apr 14 2013 toddrme2178@gmail.com
- Remove pre_checkin.sh since the two versions are not the same
* Fri Apr 12 2013 p.drouand@gmail.com
- Initial python3 support
* Tue Feb 26 2013 vuntz@opensuse.org
- Add python-six Requires: since version 0.6, the six module is
  used.
* Fri Feb  1 2013 oliver.bengs@opensuse.org
- update to 0.6
  * Added required attribute to Meta to specify which settings are required to set.
  * Moved to Travis for the tests: http://travis-ci.org/jezdez/django-appconf
  * Stopped support for Django 1.2.X.
  * Introduced support for Python >= 3.2.
* Tue Oct  9 2012 oliver.bengs@opensuse.org
- update to 0.5
  * Install as a package instead of a module.
  * Refactored tests to use django-jenkins for enn.io‘s CI server.
* Fri Jan 20 2012 saschpe@suse.de
- Minor cleanup:
  * Remove CFLAGS
  * BuildRequire python-distribute instead of setuptools
  * Reduced macro usage
* Fri Jan 20 2012 jfunk@funktronics.ca
- Initial release
